@@ -190,6 +190,22 @@ class TestAdminAPI(object):
             data=None,
         )
 
+    @mock.patch('requests.request')
+    def test_get_dashboard_by_tx_id(self, mock_request):
+        mock_request.__name__ = 'request'
+        api = AdminAPI('http://admin.api', 'token')
+        api.get_dashboard_by_tx_id('dft-some-service')
+
+        mock_request.assert_called_with(
+            'GET',
+            'http://admin.api/transactions-explorer-service/dft-some-service/dashboard',
+            headers=match_equality(has_entries({
+                'Accept': 'application/json',
+                'Authorization': 'Bearer token'
+            })),
+            data=None,
+        )
+
     @mock.patch('requests.request')
     def test_list_organisations(self, mock_request):
         mock_request.__name__ = 'request'
